@@ -162,7 +162,7 @@ fn merklize_inner(
 
         (MerkleNode::from_engine(engine), 1)
     } else {
-        let div = len / 2;
+        let div = len / 2 + len % 2;
 
         let (node1, height1) = merklize_inner(
             engine_proto,
